@@ -4,6 +4,8 @@ import sys
 import random as r
 def main():
     l=len(sys.argv)
+    print(l)
+    print(sys.argv[0],sys.argv[1])
     if(sys.argv[1]=='1'):
         if(sys.argv[2]=='1'):
             if(sys.argv[3]=='a'):
@@ -422,13 +424,9 @@ else:
         print("Batch-2")
     import os
     path="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.txt"
-    py=path="C:\\Users\\"+os.getlogin()+"\\Desktop\\output.py"
-    f=open(path,'w')
-    with open(py,'w') as f1:
-        print(s,file=f1)    
-    print(s,file=f)
+    f=open(path,'w')   
+    f.write(s)
     f.close()
-    f1.close()
 '''
     try:
         m=sys.argv[1]
